@@ -27,7 +27,7 @@
 #' @param ... Additional arguments for \code{\link{getMadratGraph}} in case
 #' that no graph is provided (otherwise ignored)
 #' @return A fingerprint (hash) of all provided sources, or "fingerprintError"
-#' @author Jan Philipp Dietrich, Pascal Führlich
+#' @author Jan Philipp Dietrich, Pascal Sauer
 #' @seealso \code{\link{readSource}}
 #' @examples
 #' madrat:::fingerprint("toolGetMapping", package = "madrat")
@@ -36,52 +36,52 @@
 fingerprint <- function(name, details = FALSE, graph = NULL, ...) {
   dependencies <- getDependencies(name, direction = "in", self = TRUE, graph = graph, ...)
   result <- tryCatch({
-      fingerprintFunctions <- dependencies$hash[robustOrder(dependencies$call)]
-      names(fingerprintFunctions) <- dependencies$call[robustOrder(dependencies$call)]
+    fingerprintFunctions <- dependencies$hash[robustOrder(dependencies$call)]
+    names(fingerprintFunctions) <- dependencies$call[robustOrder(dependencies$call)]
 
-      # handle special requests via flags
-      .tmp <- function(x) {
-        return(robustSort(sub(":+", ":::", x)))
-      }
-      ignore <- .tmp(attr(dependencies, "flags")$ignore)
-      monitor <- .tmp(attr(dependencies, "flags")$monitor)
-      # if conflicting information is giving (monitor and ignore at the same time,
-      # prioritize monitor request)
-      ignore <- setdiff(ignore, monitor)
-      # add calls from the monitor list which are not already monitored
-      fingerprintMonitored <- fingerprintCall(setdiff(monitor, names(fingerprintFunctions)))
-      # ignore functions mentioned in the ignore list
-      fingerprintFunctions <- fingerprintFunctions[setdiff(names(fingerprintFunctions), ignore)]
-      sources <- substring(dependencies$func[dependencies$type == "read"], 5)
-      if (length(sources) > 0) {
-        sources <- paste0(getConfig("sourcefolder"), "/", robustSort(sources))
-      }
-      fingerprintSources <- fingerprintFiles(sources)
-      fingerprintMappings <- fingerprintFiles(attr(dependencies, "mappings"))
-      fingerprint <- c(fingerprintFunctions, fingerprintSources, fingerprintMappings, fingerprintMonitored)
-      fingerprint <- fingerprint[robustOrder(basename(names(fingerprint)))]
-
-      # Cache files became incompatible when readSource was allowed to return non-magpie objects.
-      # Referring to madrat versions before this change as "old" and after this change as "new" here:
-      # Hashing the string "v2" leads to completely new hashes, and thus cache files with different names.
-      # Old madrat versions will never read/write these new cache files, and new madrat versions will never
-      # read/write cache files created with an old madrat version.
-      out <- digest(list("v2", unname(fingerprint)), algo = getConfig("hash"))
-
-      if (details) {
-        attr(out, "details") <- fingerprint
-        vcat(3, "hash components (", out, "):", show_prefix = FALSE)
-        for (n in names(fingerprint)) {
-          vcat(3, "  ", fingerprint[n], " | ", basename(n), " | ", n, show_prefix = FALSE)
-        }
-      }
-      out
-    },
-    error = function(error) {
-      vcat(2, paste(" - Fingerprinting failed:", error), show_prefix = FALSE)
-      return("fingerprintError")
+    # handle special requests via flags
+    .tmp <- function(x) {
+      return(robustSort(sub(":+", ":::", x)))
     }
-  )
+    ignore <- .tmp(attr(dependencies, "flags")$ignore)
+    monitor <- .tmp(attr(dependencies, "flags")$monitor)
+    # if conflicting information is giving (monitor and ignore at the same time,
+    # prioritize monitor request)
+    ignore <- setdiff(ignore, monitor)
+    # add calls from the monitor list which are not already monitored
+    fingerprintMonitored <- fingerprintCall(setdiff(monitor, names(fingerprintFunctions)))
+    # ignore functions mentioned in the ignore list
+    fingerprintFunctions <- fingerprintFunctions[setdiff(names(fingerprintFunctions), ignore)]
+
+    sources <- substring(dependencies$func[dependencies$type == "read"], 5)
+    sources <- robustSort(sources)
+    sources <- vapply(sources, function(t) getSourceFolder(type = t, subtype = NULL), character(1))
+    fingerprintSources <- fingerprintFiles(sources)
+
+    fingerprintMappings <- fingerprintFiles(attr(dependencies, "mappings"))
+    fingerprint <- c(fingerprintFunctions, fingerprintSources, fingerprintMappings, fingerprintMonitored)
+    fingerprint <- fingerprint[robustOrder(basename(names(fingerprint)))]
+
+    # Cache files became incompatible when readSource was allowed to return non-magpie objects.
+    # Referring to madrat versions before this change as "old" and after this change as "new" here:
+    # Hashing the string "v2" leads to completely new hashes, and thus cache files with different names.
+    # Old madrat versions will never read/write these new cache files, and new madrat versions will never
+    # read/write cache files created with an old madrat version.
+    out <- digest(list("v2", unname(fingerprint)), algo = getConfig("hash"))
+
+    if (details) {
+      attr(out, "details") <- fingerprint
+      vcat(3, "hash components (", out, "):", show_prefix = FALSE)
+      for (n in names(fingerprint)) {
+        vcat(3, "  ", fingerprint[n], " | ", basename(n), " | ", n, show_prefix = FALSE)
+      }
+    }
+    out
+  },
+  error = function(error) {
+    vcat(2, paste(" - Fingerprinting failed:", error), show_prefix = FALSE)
+    return("fingerprintError")
+  })
   attr(result, "call") <- dependencies$call[dependencies$func == name]
   return(result)
 }
@@ -132,18 +132,19 @@ fingerprintFiles <- function(paths) {
     }
 
     getHashCacheName <- function(path) {
-      # return file name for fileHash cache if the given path belongs to a source folder,
-      # otherwise return NULL
+      # return file name for fileHash cache if the given path belongs to the source folder
+      # (this is not the case for a redirected source folder), otherwise return NULL
       if (dir.exists(getConfig("sourcefolder")) &&
-          startsWith(normalizePath(path), normalizePath(getConfig("sourcefolder")))) {
+            startsWith(normalizePath(path), normalizePath(getConfig("sourcefolder")))) {
         return(paste0(getConfig("cachefolder"), "/fileHashCache", basename(path), ".rds"))
       } else {
         return(NULL)
       }
     }
     hashCacheFile <- getHashCacheName(path)
+    orgFiles <- files
 
-    if (!is.null(hashCacheFile) && file.exists(hashCacheFile)) {
+    if (!is.null(files) && !is.null(hashCacheFile) && file.exists(hashCacheFile)) {
       tryResult <- try({
         filesCache <- readRDS(hashCacheFile)
         # keep only entries which are still up-to-date
@@ -161,18 +162,23 @@ fingerprintFiles <- function(paths) {
     }
 
     if (!is.null(files)) {
-      # use the first 300 byte of each file and the file sizes for hashing
-      files$hash <- vapply(files$path, digest, character(1), algo = getConfig("hash"), file = TRUE, length = 300)
+      # hash the first 300 bytes of each file, or the entire file if a
+      # `.fullhash` file is present in the directory
+      files$hash <- vapply(
+        files$path,
+        digest,
+        character(1),
+        algo = getConfig("hash"),
+        file = TRUE,
+        length = ifelse(file.exists(file.path(path, ".fullhash")), Inf, 300)
+      )
       files$path <- NULL
       if (!is.null(hashCacheFile)) {
         if (!dir.exists(dirname(hashCacheFile))) {
           dir.create(dirname(hashCacheFile), recursive = TRUE)
         }
         tryCatch({
-          # write to tempfile to avoid corrupt cache files in parallel running preprocessings
-          tempfileName <- paste0(hashCacheFile, Sys.getenv("SLURM_JOB_ID", unset = ""))
-          saveRDS(files, file = tempfileName, compress = getConfig("cachecompression"))
-          file.rename(tempfileName, hashCacheFile)
+          saveRDS(orgFiles, file = hashCacheFile, compress = getConfig("cachecompression"))
           Sys.chmod(hashCacheFile, mode = "0666", use_umask = FALSE)
         }, error = function(error) {
           warning("Saving hashCacheFile failed: ", error)
