@@ -3,8 +3,8 @@
 #' Example for class of fullX functions. Can be used as template for a new function
 #' or for testing the basic functionality
 #'
-#' @param rev data revision which should be used/produced. Format must be compatible to
-#' \code{\link[base]{numeric_version}}.
+#' @param rev data revision which should be used/produced. Will be converted to
+#' \code{\link[base]{numeric_version}} when called via \code{\link{retrieveData}}.
 #' @param dev development suffix to distinguish development versions for the same data
 #' revision. This can be useful to distinguish parallel lines of development.
 #' @param extra additional argument which - when changed - does not require a re-computation
@@ -19,14 +19,14 @@
 #' retrieveData("example", rev = "2.1.2", dev = "test", regionmapping = "regionmappingH12.csv")
 #' }
 #'
-fullEXAMPLE <- function(rev = as.numeric_version("0"), dev = "", extra = "Example argument") {
+fullEXAMPLE <- function(rev = 0, dev = "", extra = "Example argument") {
   # ATTENTION: name of the model in function name must be in capital letters!
 
   "!# @pucArguments extra"
 
   writeLines(extra, "test.txt")
 
-  if (rev >= "1") {
+  if (rev >= numeric_version("1")) {
     calcOutput("TauTotal", years = 1995, round = 2, file = "fm_tau1995.cs4")
   }
   if (dev == "test") {
