@@ -1,7 +1,10 @@
 #' initializeConfig
 #'
 #' Checks whether configuration already has been set. If not, it will be initialized
-#' with default settings or (if available) system settings.
+#' with default settings or (if available) system settings. All madrat folders (see
+#' \code{\link{setConfig}} for documentation which folders are available) will be set
+#' to the system environment variables MADRAT_SOURCEFOLDER, MADRAT_CACHEFOLDER, etc.
+#' if they exist, NA otherwise. NA means subfolders of the mainfolder are used.
 #'
 #' @param verbose boolean deciding whether status information/updates should be shown or not
 #' @author Jan Philipp Dietrich
@@ -11,7 +14,9 @@ initializeConfig <- function(verbose = TRUE) {
   # check whether config has not been initialized yet
   # and initialize it (otherwise do nothing)
   if (is.null(getOption("madrat_cfg"))) {
-    if (verbose) message("\nInitialize madrat config with default settings..")
+    if (verbose) {
+      message("\nInitializing madrat config with default settings")
+    }
 
     cfg <- list(regionmapping        = "regionmappingH12.csv",
                 extramappings        = NULL,
@@ -19,12 +24,12 @@ initializeConfig <- function(verbose = TRUE) {
                 globalenv            = FALSE,
                 verbosity            = 1,
                 mainfolder           = getMainfolder(verbose = verbose),
-                sourcefolder         = NA,
-                cachefolder          = NA,
-                mappingfolder        = NA,
-                outputfolder         = NA,
-                pucfolder            = NA,
-                tmpfolder            = NA,
+                sourcefolder         = Sys.getenv("MADRAT_SOURCEFOLDER", unset = NA),
+                cachefolder          = Sys.getenv("MADRAT_CACHEFOLDER", unset = NA),
+                mappingfolder        = Sys.getenv("MADRAT_MAPPINGFOLDER", unset = NA),
+                outputfolder         = Sys.getenv("MADRAT_OUTPUTFOLDER", unset = NA),
+                pucfolder            = Sys.getenv("MADRAT_PUCFOLDER", unset = NA),
+                tmpfolder            = Sys.getenv("MADRAT_TMPFOLDER", unset = NA),
                 nolabels             = NULL,
                 forcecache           = FALSE,
                 ignorecache          = NULL,
@@ -33,10 +38,10 @@ initializeConfig <- function(verbose = TRUE) {
                 diagnostics          = FALSE,
                 debug                = FALSE,
                 maxLengthLogMessage = 200)
-     options(madrat_cfg = cfg) # nolint
-     if (verbose) {
+    options(madrat_cfg = cfg) # nolint
+    if (verbose) {
       message(paste(paste0("    ", names(cfg)), cfg, sep = " = ", collapse = "\n"))
       message("..done!\n")
-     }
+    }
   }
 }
