@@ -11,13 +11,12 @@
 #' @author Benjamin Leon Bodirsky, Jan Philipp Dietrich
 #' @export
 #' @examples
-#' toolXlargest(maxample("pop"),range=1:3)
-#' 
-toolXlargest <- function(x, range=1:20, years=NULL , elements=NULL, ...) {
-  if(!is.magpie(x)) stop("Input must be a MAgPIE object!")
+#' toolXlargest(magclass::maxample("pop"), range = 1:3)
+toolXlargest <- function(x, range = 1:20, years = NULL, elements = NULL, ...) {
+  if (!is.magpie(x)) stop("Input must be a MAgPIE object!")
   if (!is.null(years)) x <- x[, years, ]
-  if (!is.null(elements)) x <- x[,,elements]
-  tmp <- dimSums(x, dim = c(2,3))
-  out <- getRegions(tmp[robustOrder(tmp, decreasing = TRUE),,])[range]
+  if (!is.null(elements)) x <- x[, , elements]
+  tmp <- dimSums(x, dim = c(2, 3))
+  out <- out <- getItems(tmp[robustOrder(tmp, decreasing = TRUE), , ], dim = 1.1)[range]
   return(out)
 }
