@@ -1,13 +1,10 @@
-context("getCode")
-
-globalassign <- function(...) {
-  for (x in c(...)) assign(x, eval.parent(parse(text = x)), .GlobalEnv)
-}
-
 test_that("getCode works", {
- setConfig(verbosity = 1, .verbose = FALSE)
- expect_silent(a <- madrat:::getCode("madrat"))
- flags <- list(monitor = list(`madrat:::readTau` = c("madrat:::sysdata$iso_cell",
+ localConfig(verbosity = 1, .verbose = FALSE)
+ expect_silent({
+   a <- getCode("madrat")
+  })
+ flags <- list(pucArguments = list(`madrat:::fullEXAMPLE` = "extra"),
+               monitor = list(`madrat:::readTau` = c("madrat:::sysdata$iso_cell",
                                                      "magclass:::ncells")),
                ignore = list(`madrat:::readTau` = "madrat:::toolAggregate"))
  expect_identical(attr(a, "flags"), flags)
@@ -21,10 +18,8 @@ test_that("getCode works", {
    return(1)
  }
  globalassign("calcTauTotal", "calcFlagTest")
- expect_warning(a <- madrat:::getCode("madrat", globalenv = TRUE), "Duplicate functions")
+ expect_warning(a <- getCode("madrat"), "Duplicate functions")
  expect_setequal(attr(a, "flags")$ignore$calcFlagTest, c("testIgnore", "ignoreMore"))
  rm(list = c("calcTauTotal", "calcFlagTest"), envir = .GlobalEnv)
- expect_null(attr(madrat:::getCode(NULL, TRUE), "flags"))
+ expect_null(attr(getCode(NULL, TRUE), "flags"))
 })
-
-rm(list = ls(envir = .GlobalEnv), envir = .GlobalEnv)
