@@ -2,7 +2,7 @@ test_that("toolCountryFill works as expected", {
   x <- new.magpie("DEU", 1994, "bla", 0)
   expect_message(y <- toolCountryFill(x, 99), "toolCountryFill set missing values for IMPORTANT")
   expect_equal(dim(y)[1], 249)
-  expect_true(y["DEU", , ] == 0)
+  expect_true(all(y["DEU", , ] == 0))
   expect_true(all(y["DEU", , , invert = TRUE] == 99))
 
   x2 <- new.magpie(c("DEU", "XYZ"), 1994, "bla", 0)
@@ -19,9 +19,9 @@ test_that("toolCountryFill works as expected", {
 
   x3 <- new.magpie(c("DEU", "FRA"), 1994, "bla", 0)
   x3["FRA", , ] <- 42
-  expect_true(toolCountryFill(x3, 99, FRA = "DEU")["FRA", , ] == 42)
+  expect_true(all(toolCountryFill(x3, 99, FRA = "DEU")["FRA", , ] == 42))
   expect_message(y5 <- toolCountryFill(x3, 99, FRA = "DEU", overwrite = TRUE), "data overwritten")
-  expect_true(y5["FRA", , ] == 0)
+  expect_true(all(y5["FRA", , ] == 0))
 
   empty <- new.magpie(NULL, NULL, c("bla"))
   expect_silent(y6 <- toolCountryFill(empty, verbosity = 3))
