@@ -36,6 +36,14 @@ test_that("toolGetMapping works", {
   a <- 1
   save(a, file = paste0(getConfig("mappingfolder"), "/test.rda"))
   writeLines("abc", paste0(getConfig("mappingfolder"), "/test.xyz"))
-  expect_error(toolGetMapping("test.rda", where = "mappingfolder"), "did not contain a object")
+  expect_error(toolGetMapping("test.rda", where = "mappingfolder"), "did not contain an object")
   expect_error(toolGetMapping("test.xyz"), "Unsupported filetype")
+
+  readTest <- function() {
+    toolGetMapping("regionmappingH12.csv", type = "regional")
+    return(as.magpie(1))
+  }
+  globalassign("readTest")
+  expect_warning(readSource("Test"),
+                 "argument 'where' should be set when calling toolGetMapping from within a madrat function.")
 })
